scsimodepage(1m)

scsimodepage - display and edit Mode Pages for SCSI and Fibre Channel devices

As shipped in IRIX 6.5.22. Added in IRIX 6.5.19.

NAME
     scsimodepage - display and edit Mode Pages for SCSI and Fibre Channel
     devices

SYNOPSIS
     scsimodepage [-D] [-B Byte from Start of Page] [-P Page No.] [-F Ref.
     Field No.] [-V New Field/Byte Value] [-o Output LogFile] -d Device

DESCRIPTION
     scsimodepage is an interactive utility for devices accessed using the SGI
     SCSI subsystem. It sends a Mode Sense(6) command to the device to get the
     modepages, displays them in a tabular format, allows the user to change
     various fields in those pages and then sends a Mode Select(6) command to
     the device to save the changed modepages.  More information about the
     Mode Sense(6) and Mode Select(6) commands can be found in the SCSI
     Primary Commands-2 (SPC-2) reference documents.


   OPTIONS
     In the interactive mode scsimodepage is invoked with the -d devicename
     option. The device name must correspond to the 'sc' device.  A logfile to
     store modepage modifications should also be specified using the -o
     logfile option. For example :

     scsimodepage -d /dev/scsi/sc9d70l0 -o target70.log

     If a logfile is not specified, modepage changes are stored in
     scsimodepage.log in the current working directory of the user. The
     logfile is intended to facilitate the user to make the same change on
     multiple devices (all supporting the  modepages being edited).  For
     example (assuming the logfile is target70.log):

     sh target70.log /dev/scsi/sc9d71l0

     will copy the modepage changes made on sc9d70l0 to sc9d71l0.


     -P  Page No.
          specifies the number of the modepage to be edited.  Both decimal and
          hex values (preceded by 0x) are acceptable.


     -F  Ref. Field No.
          Specifies the Reference no. of the modepage field being edited.
          Cannot be used with the -B option.  Both decimal and hex values
          (preceded by 0x) are acceptable.


     -V  Value
          The new value to be placed in the specified field/byte of the page.
          Both decimal and hex values (preceded by 0x) are acceptable.
     -B  Byte No.
          Specifies the byte no. from the start of the page.  Bytes are
          numbered starting from 0 and include the bytes forming the page
          header.  This option cannot be used with the -F option.  Both
          decimal and hex values (preceded by 0x) are acceptable.


     -D   Load Default Values. This option changes the current values in the
          modepage ( specified using -P ) to their default values.


     In the interactive mode an invalid choice results in the default option
     (specified in []) being chosen. For example :

     Do you wish to modify this [n] :

     Any keystroke other than 'y' or 'Y' will result in 'n' being chosen.
     Modepage changes can result in loss of system data and this facility
     ensures that the user is fully aware of the changes being made.


EXAMPLES
     1) scsimodepage -P 0x1 -F 16 -V 0x1024 -d <device>

     In this example Field 16 (in the tabular representation) of Page 1 gets
     changed to 0x1024.

     2) scsimodepage -P 0x1 -B 16 -V 0x24 -d <device>

     In this example the 16th byte of Page 1 gets changed to 0x24.

     3) scsimodepage -P 0x1 -D -d <device>

     In this example the current values of ModePage 1 are changed to their
     default values.



FILES
     /dev/scsi/sc*d*l* - the generic 'sc' scsi driver device

SEE ALSO
     scsicontrol(1M), scsiha(1M), scsidiskformat(1M), scsidisktest(1M).

NOTE
     This command is normally usable only by the superuser, because the
     standard permissions of the devices in /dev/scsi restrict access to other
     users.